diff --git a/README.md b/README.md
index e884213c..ce702b6a 100644
--- a/README.md
+++ b/README.md
@@ -1,6 +1,6 @@
-Coedit is an IDE for the [D programming language](https://dlang.org), its compilers, tools and libraries.
+_D Extended EDitor_ is an IDE for the [D programming language](https://dlang.org), its compilers, tools and libraries.
-[](https://bbasile.github.io/Coedit/img/coedit_kde4.png)
+[](https://bbasile.github.io/dexed/img/coedit_kde4.png)
**Overview**
---
@@ -17,10 +17,10 @@ Coedit is an IDE for the [D programming language](https://dlang.org), its compil
- Debugging with a GDB gui. (**linux only**)
- Integrated terminal emulator. (**linux only**)
- Tree of symbols in the current module.
-- static library manager that supports auto-registration from local DUB projects, from online DUB packages or from Coedit custom project format.
+- static library manager that supports auto-registration from local DUB projects, from online DUB packages or from dexed custom project format.
- todo list based on the _todo comments_ located in a project or in the current source.
- user-defined tools powered by a string interpolation system.
-- integrated file browser, dfmt interface, search & replace, [discover more in the manual](https://bbasile.github.io/Coedit/).
+- integrated file browser, dfmt interface, search & replace, [discover more in the manual](https://bbasile.github.io/dexed/).
**Project information**
---
@@ -34,19 +34,19 @@ Coedit is an IDE for the [D programming language](https://dlang.org), its compil
Download the zipped binaries or the zip that contains the setup program for you platform:
-- :package: [setup program for Linux 64 bit](https://github.com/BBasile/Coedit/releases/download/v3.6.20/coedit.3.6.20.linux64.setup.zip)
-- :package: [binaries for Linux 64 bit](https://github.com/BBasile/Coedit/releases/download/v3.6.20/coedit.3.6.20.linux64.zip)
-- :package: [setup program for Windows 32/64 bit](https://github.com/BBasile/Coedit/releases/download/v3.6.20/coedit.3.6.20.win32.setup.zip)
-- :package: [binaries for Windows 32/64 bit](https://github.com/BBasile/Coedit/releases/download/v3.6.20/coedit.3.6.20.win32.zip)
-- :package: [rpm for Linux 64 bit](https://github.com/BBasile/Coedit/releases/download/v3.6.20/coedit-3.6.20-0.x86_64.rpm)
-- :package: [deb for Linux 64 bit](https://github.com/BBasile/Coedit/releases/download/v3.6.20/coedit-3.6.20.amd64.deb)
+- :package: [setup program for Linux 64 bit](https://github.com/BBasile/dexed/releases/download/v3.6.20/coedit.3.6.20.linux64.setup.zip)
+- :package: [binaries for Linux 64 bit](https://github.com/BBasile/dexed/releases/download/v3.6.20/coedit.3.6.20.linux64.zip)
+- :package: [setup program for Windows 32/64 bit](https://github.com/BBasile/dexed/releases/download/v3.6.20/coedit.3.6.20.win32.setup.zip)
+- :package: [binaries for Windows 32/64 bit](https://github.com/BBasile/dexed/releases/download/v3.6.20/coedit.3.6.20.win32.zip)
+- :package: [rpm for Linux 64 bit](https://github.com/BBasile/dexed/releases/download/v3.6.20/coedit-3.6.20-0.x86_64.rpm)
+- :package: [deb for Linux 64 bit](https://github.com/BBasile/dexed/releases/download/v3.6.20/coedit-3.6.20.amd64.deb)
The _zip_ archives allow to move freely the files.
The _setup.zip_ archives contains a command line program that installs to predefined locations so that the software can be run without additional intervention.
The _deb_ and the _rpm_ packages are for those who prefer the official setup system for their linux systems.
-Linux 32 bits version must be [built manually](https://bbasile.github.io/Coedit/build.html).
+Linux 32 bits version must be [built manually](https://bbasile.github.io/dexed/build.html).
-[**See this page**](https://bbasile.github.io/Coedit/setup.html) for more information about the setup.
+[**See this page**](https://bbasile.github.io/dexed/setup.html) for more information about the setup.
Download 3rd part packages, maintained by volunteers, but the available versions are not guaranteed to be the latest:
@@ -56,4 +56,4 @@ Download 3rd part packages, maintained by volunteers, but the available versions
**Build**
---
-Follow the procedure described [**here**](https://bbasile.github.io/Coedit/build.html).
+Follow the procedure described [**here**](https://bbasile.github.io/dexed/build.html).
diff --git a/cesetup/nux32/readme.md b/cesetup/nux32/readme.md
deleted file mode 100644
index f34219ca..00000000
--- a/cesetup/nux32/readme.md
+++ /dev/null
@@ -1 +0,0 @@
-to fill with the files the installer will extract
\ No newline at end of file
diff --git a/cesetup/nux64/readme.md b/cesetup/nux64/readme.md
deleted file mode 100644
index f34219ca..00000000
--- a/cesetup/nux64/readme.md
+++ /dev/null
@@ -1 +0,0 @@
-to fill with the files the installer will extract
\ No newline at end of file
diff --git a/cesetup/win32/readme.md b/cesetup/win32/readme.md
deleted file mode 100644
index f34219ca..00000000
--- a/cesetup/win32/readme.md
+++ /dev/null
@@ -1 +0,0 @@
-to fill with the files the installer will extract
\ No newline at end of file
diff --git a/cesetup/zip-nux32.sh b/cesetup/zip-nux32.sh
deleted file mode 100644
index 6adca6b9..00000000
--- a/cesetup/zip-nux32.sh
+++ /dev/null
@@ -1,12 +0,0 @@
-ver=`cat version.txt`
-fld=coedit-x86
-cd nux32
-mkdir $fld/
-cp * $fld/
-zip -9 \
-../output/coedit.${ver:1:100}.linux32.zip \
-$fld/dcd.license.txt $fld/coedit.license.txt \
-$fld/coedit $fld/dastworx \
-$fld/coedit.ico $fld/coedit.png \
-$fld/dcd-server $fld/dcd-client $fld/dscanner
-rm -rf coedit-x86
diff --git a/cesetup/zip-nux64.sh b/cesetup/zip-nux64.sh
deleted file mode 100644
index 84085330..00000000
--- a/cesetup/zip-nux64.sh
+++ /dev/null
@@ -1,12 +0,0 @@
-ver=`cat version.txt`
-fld=coedit-x86_64
-cd nux64
-mkdir $fld/
-cp * $fld/
-zip -9 \
-../output/coedit.${ver:1:100}.linux64.zip \
-$fld/dcd.license.txt $fld/coedit.license.txt \
-$fld/coedit $fld/dastworx \
-$fld/coedit.ico $fld/coedit.png \
-$fld/dcd-server $fld/dcd-client $fld/dscanner
-rm -rf coedit-x86_64
diff --git a/dastworx/dastworx.ce b/dastworx/dastworx.dxp
similarity index 100%
rename from dastworx/dastworx.ce
rename to dastworx/dastworx.dxp
diff --git a/dastworx/dastworx.cegrp b/dastworx/dastworx.grp
similarity index 100%
rename from dastworx/dastworx.cegrp
rename to dastworx/dastworx.grp
diff --git a/dastworx/readme.md b/dastworx/readme.md
index 506059db..7066f866 100644
--- a/dastworx/readme.md
+++ b/dastworx/readme.md
@@ -1,15 +1,15 @@
## Dastworx
-_D AST works_ is a tool that processes the AST of a D module to extract several information used by Coedit.
+_D AST works_ is a tool that processes the AST of a D module to extract several information used by dexed.
It's notably used by the _symbol list_ and the _todo list_ widgets.
## Build
-If Coedit is build manually you'll certainly have to build _dastworx_ too.
+If dexed is build manually you certainly have to build _dastworx_ too.
Two options exist.
-#### Using Coedit & the submodules
+#### Using dexed & the submodules
- If you've cloned this repository, make sure that the submodule are also here with `git submodule update --init`.
- In Coedit open the project `dastworx.ce`.
@@ -19,4 +19,4 @@ Two options exist.
#### Using the scripts
- Windows: `build.bat`
-- Linux: `sh ./build.sh`
\ No newline at end of file
+- Linux: `sh ./build.sh`
diff --git a/lazproj/cedast_loader.lpi b/lazproj/cedast_loader.lpi
deleted file mode 100644
index 7ea44914..00000000
--- a/lazproj/cedast_loader.lpi
+++ /dev/null
@@ -1,65 +0,0 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
diff --git a/lazproj/coedit.ico b/lazproj/dexed.ico
similarity index 100%
rename from lazproj/coedit.ico
rename to lazproj/dexed.ico
diff --git a/lazproj/coedit.lpi b/lazproj/dexed.lpi
similarity index 94%
rename from lazproj/coedit.lpi
rename to lazproj/dexed.lpi
index 3cbd5685..a44d788a 100644
--- a/lazproj/coedit.lpi
+++ b/lazproj/dexed.lpi
@@ -6,7 +6,7 @@
-
+
@@ -344,55 +344,55 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
@@ -405,7 +405,7 @@
-
+
@@ -451,7 +451,7 @@
-
+
@@ -527,7 +527,7 @@
-
+
@@ -847,7 +847,7 @@
-
+
diff --git a/lazproj/coedit.lpr b/lazproj/dexed.lpr
similarity index 97%
rename from lazproj/coedit.lpr
rename to lazproj/dexed.lpr
index 60031098..d6a981dd 100644
--- a/lazproj/coedit.lpr
+++ b/lazproj/dexed.lpr
@@ -1,4 +1,4 @@
-program coedit;
+program dexed;
{$mode objfpc}{$H+}
diff --git a/cesetup/.gitignore b/setup/.gitignore
similarity index 100%
rename from cesetup/.gitignore
rename to setup/.gitignore
diff --git a/cesetup/deb.sh b/setup/deb.sh
similarity index 87%
rename from cesetup/deb.sh
rename to setup/deb.sh
index c7ed2b4e..66cd4fbf 100644
--- a/cesetup/deb.sh
+++ b/setup/deb.sh
@@ -10,7 +10,7 @@ else
arch="i386"
fi
-name=coedit-$ver.$arch
+name=dexed-$ver.$arch
basdir=$HOME/$name/
cfgdir=$basdir/DEBIAN
@@ -24,23 +24,23 @@ mkdir -p $bindir
mkdir -p $pixdir
mkdir -p $shcdir
-cp nux64/coedit $bindir
+cp nux64/dexed $bindir
cp nux64/dastworx $bindir
-cp nux64/coedit.png $pixdir
+cp nux64/dexed.png $pixdir
echo "[Desktop Entry]
Categories=Application;IDE;Development;
-Exec=coedit %f
-GenericName=coedit
-Icon=coedit
+Exec=dexed %f
+GenericName=dexed
+Icon=dexed
Keywords=editor;Dlang;IDE;dmd;
-Name=coedit
+Name=dexed
StartupNotify=true
Terminal=false
-Type=Application" > $shcdir/coedit.desktop
+Type=Application" > $shcdir/dexed.desktop
cd $cfgdir
-echo "Package: coedit
+echo "Package: dexed
Version: $ver
Section: devel
Priority: optional
diff --git a/cesetup/readme.md b/setup/readme.md
similarity index 85%
rename from cesetup/readme.md
rename to setup/readme.md
index a981d606..f1de6a1f 100644
--- a/cesetup/readme.md
+++ b/setup/readme.md
@@ -1,10 +1,10 @@
-This folder contains the files necessary to make a Coedit release.
-The process is semi-automatic and achieved by compiling a project in Coedit itself.
+This folder contains the files necessary to make a dexed release.
+The process is semi-automatic and achieved by compiling a project in dexed itself.
-Coedit setup program
+dexed setup program
===
-This coedit project (_cesetup.coedit_) creates the coedit setup program.
+This dexed project (_cesetup.dexed_) creates the dexed setup program.
The project contains 3 configurations named _win32_, _nux32_, _nux64.
Each takes the content of the matching sub-folder and puts it in the output folder, as an extractor program,
at compile time (using the `import(file)` expression).
diff --git a/cesetup/rpm.sh b/setup/rpm.sh
similarity index 75%
rename from cesetup/rpm.sh
rename to setup/rpm.sh
index 46f10ff7..e01c6515 100644
--- a/cesetup/rpm.sh
+++ b/setup/rpm.sh
@@ -3,7 +3,7 @@ maj=${ver:0:1}
ver=${ver:1:100}
dte=$(LC_TIME='en_EN.UTF-8' date -u +"%a %b %d %Y")
arch=`uname -m`
-specname=coedit-$arch.spec
+specname=dexed-$arch.spec
cp_trgt=$(pwd)/output
semver_regex() {
@@ -32,7 +32,7 @@ if [ $lbl == '_' ]; then
lbl='0'
fi
-name_and_ver=coedit-$maj.$min.$pch-$lbl.$arch
+name_and_ver=dexed-$maj.$min.$pch-$lbl.$arch
buildroot=$HOME/rpmbuild/BUILDROOT/$name_and_ver
bindir=$buildroot/usr/bin
pixdir=$buildroot/usr/share/pixmaps
@@ -43,42 +43,42 @@ mkdir -p $bindir
mkdir -p $pixdir
mkdir -p $shcdir
-cp nux64/coedit $bindir
+cp nux64/dexed $bindir
cp nux64/dastworx $bindir
-cp nux64/coedit.png $pixdir
+cp nux64/dexed.png $pixdir
echo "[Desktop Entry]
Categories=Application;IDE;Development;
-Exec=coedit %f
-GenericName=coedit
-Icon=coedit
+Exec=dexed %f
+GenericName=dexed
+Icon=dexed
Keywords=editor;Dlang;IDE;dmd;
-Name=coedit
+Name=dexed
StartupNotify=true
Terminal=false
-Type=Application" > $shcdir/coedit.desktop
+Type=Application" > $shcdir/dexed.desktop
cd $HOME/rpmbuild/SPECS
-echo "Name: coedit
+echo "Name: dexed
Version: $maj.$min.$pch
Release: $lbl
Summary: IDE for the D programming language
License: Boost
-URL: www.github.com/BBasile/Coedit
+URL: www.github.com/BBasile/dexed
Requires: gtk2, glibc, cairo, libX11, vte
%description
-Coedit is an IDE for the DMD D compiler.
+Dexed is an IDE for the DMD D compiler.
%files
/usr/bin/dastworx
-/usr/bin/coedit
-/usr/share/applications/coedit.desktop
-/usr/share/pixmaps/coedit.png
+/usr/bin/dexed
+/usr/share/applications/dexed.desktop
+/usr/share/pixmaps/dexed.png
%changelog
* $dte Basile Burg b2.temp@gmx.com
-- see https://github.com/BBasile/Coedit/releases/tag/$ver
+- see https://github.com/BBasile/dexed/releases/tag/$ver
">$specname
rpmbuild -ba $specname
diff --git a/cesetup/cesetup.d b/setup/setup.d
similarity index 94%
rename from cesetup/cesetup.d
rename to setup/setup.d
index 772e914c..53dbb19b 100644
--- a/cesetup/cesetup.d
+++ b/setup/setup.d
@@ -34,11 +34,11 @@ struct Resource
immutable Resource[] ceResources =
[
- Resource(cast(ImpType) import("coedit" ~ exeExt), "coedit" ~ exeExt, Kind.exe),
+ Resource(cast(ImpType) import("dexed" ~ exeExt), "dexed" ~ exeExt, Kind.exe),
Resource(cast(ImpType) import("dastworx" ~ exeExt), "dastworx" ~ exeExt, Kind.exe),
- Resource(cast(ImpType) import("coedit.ico"), "coedit.ico", Kind.dat),
- Resource(cast(ImpType) import("coedit.png"), "coedit.png", Kind.dat),
- Resource(cast(ImpType) import("coedit.license.txt"), "coedit.license.txt", Kind.doc)
+ Resource(cast(ImpType) import("dexed.ico"), "dexed.ico", Kind.dat),
+ Resource(cast(ImpType) import("dexed.png"), "dexed.png", Kind.dat),
+ Resource(cast(ImpType) import("dexed.license.txt"), "dexed.license.txt", Kind.doc)
];
immutable Resource[] thirdPartBinaries =
@@ -233,14 +233,14 @@ void main(string[] args)
// check that uninstall is executed as install (sudo or not)
version(linux)
{
- if (!asSu && exists("/usr/bin/coedit"))
+ if (!asSu && exists("/usr/bin/dexed"))
{
Formater.separate;
Formater.justify!'L'("warning, CE seems to be installed with sudo");
Formater.justify!'L'("but the uninstaller is not launched with sudo.");
Formater.separate;
}
- else if (asSu && exists("/home/" ~ environment.get("USER") ~ "/bin/coedit"))
+ else if (asSu && exists("/home/" ~ environment.get("USER") ~ "/bin/dexed"))
{
Formater.separate;
Formater.justify!'L'("warning, CE seems not to be installed with sudo");
@@ -374,7 +374,7 @@ void postInstall()
char[MAX_PATH] _desktopFolder;
SHGetFolderPathA(null, CSIDL_DESKTOPDIRECTORY, null, 0, _desktopFolder.ptr);
char[] desktopFolder = _desktopFolder.ptr.fromStringz();
- string target = exePath ~ "coedit.exe";
+ string target = exePath ~ "dexed.exe";
string wdir = exePath ~ "";
const(wchar)* linkPath = buildNormalizedPath(desktopFolder, "Coedit.lnk").toUTF16z();
@@ -392,12 +392,12 @@ void postInstall()
else version(linux)
{
mkdirRecurse(shortCutPath);
- File f = File(shortCutPath ~ "coedit.desktop", "w");
+ File f = File(shortCutPath ~ "dexed.desktop", "w");
f.writeln("[Desktop Entry]");
- f.writeln("Name=coedit");
+ f.writeln("Name=dexed");
f.writeln("Path=" ~ exePath);
- f.writeln("Exec=" ~ exePath ~ "coedit %f");
- f.writeln("Icon=" ~ datPath ~ "coedit.png");
+ f.writeln("Exec=" ~ exePath ~ "dexed %f");
+ f.writeln("Icon=" ~ datPath ~ "dexed.png");
f.writeln("Type=Application");
f.writeln("Categories=Application;IDE;Development;");
f.writeln("Keywords=editor;Dlang;IDE;dmd;");
@@ -416,7 +416,7 @@ void postUninstall()
}
else version(linux)
{
- tryRemove(shortCutPath ~ "coedit.desktop");
+ tryRemove(shortCutPath ~ "dexed.desktop");
}
}
diff --git a/cesetup/cesetup.coedit b/setup/setup.dxp
similarity index 92%
rename from cesetup/cesetup.coedit
rename to setup/setup.dxp
index 2a68e4e7..462fbae9 100644
--- a/cesetup/cesetup.coedit
+++ b/setup/setup.dxp
@@ -7,7 +7,7 @@ object CurrentProject: TCENativeProject
outputOptions.boundsCheck = offAlways
outputOptions.optimizations = True
outputOptions.release = True
- pathsOptions.outputFilename = 'output/coedit..win32.setup'
+ pathsOptions.outputFilename = 'output/dexed..win32.setup'
pathsOptions.importStringPaths.Strings = (
'win32/'
''
@@ -35,7 +35,7 @@ object CurrentProject: TCENativeProject
outputOptions.boundsCheck = offAlways
outputOptions.optimizations = True
outputOptions.release = True
- pathsOptions.outputFilename = 'output/coedit..linux32.setup'
+ pathsOptions.outputFilename = 'output/dexed..linux32.setup'
pathsOptions.importStringPaths.Strings = (
'nux32/'
''
@@ -60,7 +60,7 @@ object CurrentProject: TCENativeProject
outputOptions.boundsCheck = offAlways
outputOptions.optimizations = True
outputOptions.release = True
- pathsOptions.outputFilename = 'output/coedit..linux64.setup'
+ pathsOptions.outputFilename = 'output/dexed..linux64.setup'
pathsOptions.importStringPaths.Strings = (
'nux64/'
''
@@ -81,7 +81,7 @@ object CurrentProject: TCENativeProject
runOptions.options = [poUsePipes]
end>
Sources.Strings = (
- 'cesetup.d'
+ 'setup.d'
)
ConfigurationIndex = 2
version = '3.6.20'
diff --git a/cesetup/setupzip-nux-noarch.sh b/setup/setupzip-nux-noarch.sh
similarity index 100%
rename from cesetup/setupzip-nux-noarch.sh
rename to setup/setupzip-nux-noarch.sh
diff --git a/cesetup/setupzip-win32.bat b/setup/setupzip-win32.bat
similarity index 100%
rename from cesetup/setupzip-win32.bat
rename to setup/setupzip-win32.bat
diff --git a/cesetup/version.txt b/setup/version.txt
similarity index 100%
rename from cesetup/version.txt
rename to setup/version.txt
diff --git a/setup/zip-nux32.sh b/setup/zip-nux32.sh
new file mode 100644
index 00000000..277a37ac
--- /dev/null
+++ b/setup/zip-nux32.sh
@@ -0,0 +1,12 @@
+ver=`cat version.txt`
+fld=dexed-x86
+cd nux32
+mkdir $fld/
+cp * $fld/
+zip -9 \
+../output/dexed.${ver:1:100}.linux32.zip \
+$fld/dcd.license.txt $fld/dexed.license.txt \
+$fld/dexed $fld/dastworx \
+$fld/dexed.ico $fld/dexed.png \
+$fld/dcd-server $fld/dcd-client $fld/dscanner
+rm -rf dexed-x86
diff --git a/setup/zip-nux64.sh b/setup/zip-nux64.sh
new file mode 100644
index 00000000..f284d316
--- /dev/null
+++ b/setup/zip-nux64.sh
@@ -0,0 +1,12 @@
+ver=`cat version.txt`
+fld=dexed-x86_64
+cd nux64
+mkdir $fld/
+cp * $fld/
+zip -9 \
+../output/dexed.${ver:1:100}.linux64.zip \
+$fld/dcd.license.txt $fld/dexed.license.txt \
+$fld/dexed $fld/dastworx \
+$fld/dexed.ico $fld/dexed.png \
+$fld/dcd-server $fld/dcd-client $fld/dscanner
+rm -rf dexed-x86_64
diff --git a/cesetup/zip-win32.bat b/setup/zip-win32.bat
similarity index 57%
rename from cesetup/zip-win32.bat
rename to setup/zip-win32.bat
index e5f190eb..3c9b97e9 100644
--- a/cesetup/zip-win32.bat
+++ b/setup/zip-win32.bat
@@ -3,8 +3,8 @@ set ver=%ver:~1%
cd win32
:: assuming 7zip binary folder is somewhere in PATH
7z a -tzip -mx9^
- ..\output\coedit.%ver%.win32.zip^
- dcd.license.txt coedit.license.txt^
- coedit.exe dastworx.exe^
- coedit.ico coedit.png^
+ ..\output\dexed.%ver%.win32.zip^
+ dcd.license.txt dexed.license.txt^
+ dexed.exe dastworx.exe^
+ dexed.ico dexed.png^
dcd-server.exe dcd-client.exe dscanner.exe
diff --git a/src/ce_compilers.lfm b/src/ce_compilers.lfm
index a1cdf874..35370ef1 100644
--- a/src/ce_compilers.lfm
+++ b/src/ce_compilers.lfm
@@ -6,36 +6,37 @@ object CompilersPathsEditor: TCompilersPathsEditor
Caption = 'CompilersPathsEditor'
ClientHeight = 900
ClientWidth = 460
- LCLVersion = '1.8.2.0'
+ LCLVersion = '1.8.4.0'
+ Visible = False
object ScrollBox1: TScrollBox
Left = 0
Height = 900
Top = 0
Width = 460
- HorzScrollBar.Page = 189
- VertScrollBar.Page = 796
+ HorzScrollBar.Page = 116
+ VertScrollBar.Page = 898
Align = alClient
AutoSize = True
- ClientHeight = 896
- ClientWidth = 456
+ ClientHeight = 898
+ ClientWidth = 443
TabOrder = 0
object grpDMD: TGroupBox
Left = 0
- Height = 149
- Top = 51
- Width = 456
+ Height = 175
+ Top = 52
+ Width = 443
Align = alTop
AutoSize = True
Caption = 'DMD'
- ClientHeight = 129
- ClientWidth = 452
+ ClientHeight = 156
+ ClientWidth = 439
TabOrder = 0
object selDMDexe: TFileNameEdit
Left = 2
- Height = 23
+ Height = 27
Hint = 'select the compiler'
- Top = 18
- Width = 448
+ Top = 23
+ Width = 435
FilterIndex = 0
HideDirectories = False
ButtonWidth = 23
@@ -49,10 +50,10 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object selDMDrt: TDirectoryEdit
Left = 2
- Height = 23
+ Height = 27
Hint = 'select the root of druntime sources'
- Top = 61
- Width = 448
+ Top = 75
+ Width = 435
ShowHidden = False
ButtonWidth = 23
NumGlyphs = 1
@@ -65,10 +66,10 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object selDMDstd: TDirectoryEdit
Left = 2
- Height = 23
+ Height = 27
Hint = 'select the root of phobos sources'
- Top = 104
- Width = 448
+ Top = 127
+ Width = 435
ShowHidden = False
ButtonWidth = 23
NumGlyphs = 1
@@ -81,9 +82,9 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object StaticText1: TStaticText
Left = 0
- Height = 16
+ Height = 21
Top = 0
- Width = 452
+ Width = 439
Align = alTop
Alignment = taCenter
AutoSize = True
@@ -92,9 +93,9 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object StaticText2: TStaticText
Left = 0
- Height = 16
- Top = 43
- Width = 452
+ Height = 21
+ Top = 52
+ Width = 439
Align = alTop
Alignment = taCenter
AutoSize = True
@@ -103,9 +104,9 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object StaticText3: TStaticText
Left = 0
- Height = 16
- Top = 86
- Width = 452
+ Height = 21
+ Top = 104
+ Width = 439
Align = alTop
Alignment = taCenter
AutoSize = True
@@ -115,21 +116,21 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object grpGDC: TGroupBox
Left = 0
- Height = 149
- Top = 200
- Width = 456
+ Height = 175
+ Top = 227
+ Width = 443
Align = alTop
AutoSize = True
Caption = 'GDC'
- ClientHeight = 129
- ClientWidth = 452
+ ClientHeight = 156
+ ClientWidth = 439
TabOrder = 1
object selGDCexe: TFileNameEdit
Left = 2
- Height = 23
+ Height = 27
Hint = 'select the compiler'
- Top = 18
- Width = 448
+ Top = 23
+ Width = 435
FilterIndex = 0
HideDirectories = False
ButtonWidth = 23
@@ -143,10 +144,10 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object selGDCrt: TDirectoryEdit
Left = 2
- Height = 23
+ Height = 27
Hint = 'select the root of druntime sources'
- Top = 61
- Width = 448
+ Top = 75
+ Width = 435
ShowHidden = False
ButtonWidth = 23
NumGlyphs = 1
@@ -159,10 +160,10 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object selGDCstd: TDirectoryEdit
Left = 2
- Height = 23
+ Height = 27
Hint = 'select the root of phobos sources'
- Top = 104
- Width = 448
+ Top = 127
+ Width = 435
ShowHidden = False
ButtonWidth = 23
NumGlyphs = 1
@@ -175,9 +176,9 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object StaticText4: TStaticText
Left = 0
- Height = 16
+ Height = 21
Top = 0
- Width = 452
+ Width = 439
Align = alTop
Alignment = taCenter
AutoSize = True
@@ -186,9 +187,9 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object StaticText5: TStaticText
Left = 0
- Height = 16
- Top = 43
- Width = 452
+ Height = 21
+ Top = 52
+ Width = 439
Align = alTop
Alignment = taCenter
AutoSize = True
@@ -197,9 +198,9 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object StaticText6: TStaticText
Left = 0
- Height = 16
- Top = 86
- Width = 452
+ Height = 21
+ Top = 104
+ Width = 439
Align = alTop
Alignment = taCenter
AutoSize = True
@@ -209,21 +210,21 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object grpLDC: TGroupBox
Left = 0
- Height = 149
- Top = 349
- Width = 456
+ Height = 175
+ Top = 402
+ Width = 443
Align = alTop
AutoSize = True
Caption = 'LDC'
- ClientHeight = 129
- ClientWidth = 452
+ ClientHeight = 156
+ ClientWidth = 439
TabOrder = 2
object selLDCexe: TFileNameEdit
Left = 2
- Height = 23
+ Height = 27
Hint = 'select the compiler'
- Top = 18
- Width = 448
+ Top = 23
+ Width = 435
FilterIndex = 0
HideDirectories = False
ButtonWidth = 23
@@ -237,10 +238,10 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object selLDCrt: TDirectoryEdit
Left = 2
- Height = 23
+ Height = 27
Hint = 'select the root of LDC runtime & phobos sources (can be a common folder)'
- Top = 61
- Width = 448
+ Top = 75
+ Width = 435
ShowHidden = False
ButtonWidth = 23
NumGlyphs = 1
@@ -253,10 +254,10 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object selLDCstd: TDirectoryEdit
Left = 2
- Height = 23
+ Height = 27
Hint = 'select the root of phobos sources (can be empty)'
- Top = 104
- Width = 448
+ Top = 127
+ Width = 435
ShowHidden = False
ButtonWidth = 23
NumGlyphs = 1
@@ -269,9 +270,9 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object StaticText7: TStaticText
Left = 0
- Height = 16
+ Height = 21
Top = 0
- Width = 452
+ Width = 439
Align = alTop
Alignment = taCenter
AutoSize = True
@@ -280,9 +281,9 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object StaticText8: TStaticText
Left = 0
- Height = 16
- Top = 43
- Width = 452
+ Height = 21
+ Top = 52
+ Width = 439
Align = alTop
Alignment = taCenter
AutoSize = True
@@ -291,9 +292,9 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object StaticText9: TStaticText
Left = 0
- Height = 16
- Top = 86
- Width = 452
+ Height = 21
+ Top = 104
+ Width = 439
Align = alTop
Alignment = taCenter
AutoSize = True
@@ -303,21 +304,21 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object grpUSER1: TGroupBox
Left = 0
- Height = 149
- Top = 498
- Width = 456
+ Height = 175
+ Top = 577
+ Width = 443
Align = alTop
AutoSize = True
Caption = 'User 1'
- ClientHeight = 129
- ClientWidth = 452
+ ClientHeight = 156
+ ClientWidth = 439
TabOrder = 3
object selUSER1exe: TFileNameEdit
Left = 2
- Height = 23
+ Height = 27
Hint = 'select the compiler'
- Top = 18
- Width = 448
+ Top = 23
+ Width = 435
FilterIndex = 0
HideDirectories = False
ButtonWidth = 23
@@ -331,10 +332,10 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object selUSER1rt: TDirectoryEdit
Left = 2
- Height = 23
+ Height = 27
Hint = 'select the root of druntime sources'
- Top = 61
- Width = 448
+ Top = 75
+ Width = 435
ShowHidden = False
ButtonWidth = 23
NumGlyphs = 1
@@ -347,10 +348,10 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object selUSER1std: TDirectoryEdit
Left = 2
- Height = 23
+ Height = 27
Hint = 'select the root of phobos sources'
- Top = 104
- Width = 448
+ Top = 127
+ Width = 435
ShowHidden = False
ButtonWidth = 23
NumGlyphs = 1
@@ -363,9 +364,9 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object StaticText10: TStaticText
Left = 0
- Height = 16
+ Height = 21
Top = 0
- Width = 452
+ Width = 439
Align = alTop
Alignment = taCenter
AutoSize = True
@@ -374,9 +375,9 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object StaticText11: TStaticText
Left = 0
- Height = 16
- Top = 43
- Width = 452
+ Height = 21
+ Top = 52
+ Width = 439
Align = alTop
Alignment = taCenter
AutoSize = True
@@ -385,9 +386,9 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object StaticText12: TStaticText
Left = 0
- Height = 16
- Top = 86
- Width = 452
+ Height = 21
+ Top = 104
+ Width = 439
Align = alTop
Alignment = taCenter
AutoSize = True
@@ -397,21 +398,21 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object grpUSER2: TGroupBox
Left = 0
- Height = 149
- Top = 647
- Width = 456
+ Height = 175
+ Top = 752
+ Width = 443
Align = alTop
AutoSize = True
Caption = 'User 2'
- ClientHeight = 129
- ClientWidth = 452
+ ClientHeight = 156
+ ClientWidth = 439
TabOrder = 4
object selUSER2exe: TFileNameEdit
Left = 2
- Height = 23
+ Height = 27
Hint = 'select the compiler'
- Top = 18
- Width = 448
+ Top = 23
+ Width = 435
FilterIndex = 0
HideDirectories = False
ButtonWidth = 23
@@ -425,10 +426,10 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object selUSER2rt: TDirectoryEdit
Left = 2
- Height = 23
+ Height = 27
Hint = 'select the root of druntime sources'
- Top = 61
- Width = 448
+ Top = 75
+ Width = 435
ShowHidden = False
ButtonWidth = 23
NumGlyphs = 1
@@ -441,10 +442,10 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object selUSER2std: TDirectoryEdit
Left = 2
- Height = 23
+ Height = 27
Hint = 'select the root of phobos sources'
- Top = 104
- Width = 448
+ Top = 127
+ Width = 435
ShowHidden = False
ButtonWidth = 23
NumGlyphs = 1
@@ -457,9 +458,9 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object StaticText13: TStaticText
Left = 0
- Height = 16
+ Height = 21
Top = 0
- Width = 452
+ Width = 439
Align = alTop
Alignment = taCenter
AutoSize = True
@@ -468,9 +469,9 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object StaticText14: TStaticText
Left = 0
- Height = 16
- Top = 43
- Width = 452
+ Height = 21
+ Top = 52
+ Width = 439
Align = alTop
Alignment = taCenter
AutoSize = True
@@ -479,9 +480,9 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object StaticText15: TStaticText
Left = 0
- Height = 16
- Top = 86
- Width = 452
+ Height = 21
+ Top = 104
+ Width = 439
Align = alTop
Alignment = taCenter
AutoSize = True
@@ -491,24 +492,24 @@ object CompilersPathsEditor: TCompilersPathsEditor
end
object GroupBox6: TGroupBox
Left = 0
- Height = 51
+ Height = 52
Top = 0
- Width = 456
+ Width = 443
Align = alTop
AutoSize = True
Caption = 'Default compiler for completion'
- ClientHeight = 31
- ClientWidth = 452
+ ClientHeight = 33
+ ClientWidth = 439
TabOrder = 5
object selDefault: TComboBox
Left = 4
- Height = 23
+ Height = 25
Hint = 'select which the compiler for which the library paths are used by the completion daemon'
Top = 4
- Width = 444
+ Width = 431
Align = alClient
BorderSpacing.Around = 4
- ItemHeight = 15
+ ItemHeight = 0
ItemIndex = 0
Items.Strings = (
'DMD'
diff --git a/src/ce_compilers.pas b/src/ce_compilers.pas
index 9cace22d..0cf98b0c 100644
--- a/src/ce_compilers.pas
+++ b/src/ce_compilers.pas
@@ -175,7 +175,7 @@ begin
fPaths:= TCompilersPaths.Create(self);
fPathsBackup:= TCompilersPaths.Create(self);
- fname := getCoeditDocPath + optFname;
+ fname := getDocPath + optFname;
if fname.fileExists then
fPaths.loadFromFile(fname);
if not isCompilerValid(dmd) then
@@ -231,7 +231,7 @@ end;
destructor TCompilersPathsEditor.destroy;
begin
- fPaths.saveToFile(getCoeditDocPath + optFname);
+ fPaths.saveToFile(getDocPath + optFname);
EntitiesConnector.removeObserver(self);
inherited;
end;
@@ -475,7 +475,7 @@ begin
if fPaths.wouldNeedRestart and fPaths.modified then
begin
if not DCDWrapper.launchedByCe then
- dlgOkInfo('Coedit and DCD must be restarted manually in order to cache'
+ dlgOkInfo('Dexed and DCD must be restarted manually in order to cache'
+ ' the right runtime and the standard library versions.')
else
begin
diff --git a/src/ce_controls.pas b/src/ce_controls.pas
index 1b03afca..274e54f6 100644
--- a/src/ce_controls.pas
+++ b/src/ce_controls.pas
@@ -39,7 +39,7 @@ type
TPageControlButtonClick = procedure(sender: TObject; button: TCEPageControlButton) of object;
(**
- * Minimalist page-control dedicated to Coedit
+ * Minimalist page-control
*
* - get rid of the framed aspect of the default LCL one
* - no published props, no need for design time support
diff --git a/src/ce_d2synpresets.pas b/src/ce_d2synpresets.pas
index 1d1dcb24..f069f336 100644
--- a/src/ce_d2synpresets.pas
+++ b/src/ce_d2synpresets.pas
@@ -335,7 +335,7 @@ begin
inherited;
fBackup:= TCED2SynPreset.Create(nil);
fPresets:= TCED2SynPresets.Create(self);
- fname := getCoeditDocPath + optfname;
+ fname := getDocPath + optfname;
if fname.fileExists then
fPresets.loadFromFile(fname);
@@ -675,7 +675,7 @@ begin
for i:= fPresets.count-1 downto 0 do
if fPresets.preset[i].isHardCoded then
fPresets.fCollection.Delete(i);
- fPresets.saveToFile(getCoeditDocPath + optfname);
+ fPresets.saveToFile(getDocPath + optfname);
fBackup.Free;
EntitiesConnector.removeObserver(self);
inherited;
diff --git a/src/ce_dcd.pas b/src/ce_dcd.pas
index e3cc7f7a..3a53dbd7 100644
--- a/src/ce_dcd.pas
+++ b/src/ce_dcd.pas
@@ -106,7 +106,7 @@ begin
inherited;
fVersion.init('v0.0.0');
- fname := getCoeditDocPath + optsname;
+ fname := getDocPath + optsname;
if fname.fileExists then
loadFromFile(fname);
fCurrentSessionPortNum := fPortNum;
@@ -198,7 +198,7 @@ destructor TCEDcdWrapper.destroy;
var
i: integer = 0;
begin
- saveToFile(getCoeditDocPath + optsname);
+ saveToFile(getDocPath + optsname);
EntitiesConnector.removeObserver(self);
fImportCache.Free;
if fTempLines.isNotNil then
diff --git a/src/ce_dfmt.pas b/src/ce_dfmt.pas
index e88ac4ec..4a6c9890 100644
--- a/src/ce_dfmt.pas
+++ b/src/ce_dfmt.pas
@@ -105,7 +105,7 @@ begin
fDmtWrapper := TCEDmtWrapper.Create(self);
fBackup := TStringList.Create;
- fname := getCoeditDocPath + optFname;
+ fname := getDocPath + optFname;
if fname.fileExists then
fDmtWrapper.loadFromFile(fname);
@@ -138,7 +138,7 @@ end;
destructor TCEDfmtWidget.destroy;
begin
dfmtOptionEditor.TIObject := nil;
- fDmtWrapper.saveToFile(getCoeditDocPath + optFname);
+ fDmtWrapper.saveToFile(getDocPath + optFname);
fBackup.Free;
inherited;
end;
diff --git a/src/ce_dialogs.pas b/src/ce_dialogs.pas
index 737eb62b..be571549 100644
--- a/src/ce_dialogs.pas
+++ b/src/ce_dialogs.pas
@@ -47,7 +47,7 @@ const
Btns = [mbOK,mbCancel];
begin
if title = '' then
- title := 'Coedit';
+ title := 'dexed';
exit( MessageDlg(title, message, mtConfirmation, Btns, ''));
end;
@@ -56,7 +56,7 @@ const
Btns = [mbYes,mbNo];
begin
if title = '' then
- title := 'Coedit';
+ title := 'dexed';
exit( MessageDlg(title, message, mtConfirmation, Btns, ''));
end;
@@ -65,7 +65,7 @@ const
Btns = [mbOK];
begin
if title = '' then
- title := 'Coedit';
+ title := 'dexed';
exit( MessageDlg(title, message, mtInformation, Btns, ''));
end;
@@ -74,7 +74,7 @@ const
Btns = [mbOK];
begin
if title = '' then
- title := 'Coedit';
+ title := 'dexed';
exit(MessageDlg(title, message, mtError, Btns, ''));
end;
diff --git a/src/ce_dubproject.pas b/src/ce_dubproject.pas
index e229c63f..4d921651 100644
--- a/src/ce_dubproject.pas
+++ b/src/ce_dubproject.pas
@@ -599,14 +599,14 @@ begin
inherited;
fBackup := TCEDubBuildOptionsBase.Create(nil);
EntitiesConnector.addObserver(self);
- fname := getCoeditDocPath + optFname;
+ fname := getDocPath + optFname;
if fname.fileExists then
loadFromFile(fname);
end;
destructor TCEDubBuildOptions.destroy;
begin
- saveToFile(getCoeditDocPath + optFname);
+ saveToFile(getDocPath + optFname);
EntitiesConnector.removeObserver(self);
fBackup.free;
inherited;
@@ -1129,7 +1129,7 @@ begin
begin
fConfigs.Add(DubDefaultConfigName);
// default = what dub set as 'application' or 'library'
- // in this case Coedit will pass only the type to DUB: 'DUB --build=release'
+ // in this case dexed will pass only the type to DUB: 'DUB --build=release'
end;
fBuildTypes.AddStrings(DubBuiltTypeName);
@@ -1308,7 +1308,7 @@ var
begin
fBinKind := executable;
if fJSON.isNil then exit;
- // note: in Coedit this is only used to known if output can be launched
+ // note: this is only used to known if output can be launched
found := findTargetKindInd(fJSON);
conf := getCurrentCustomConfig;
if conf.isNotNil then
diff --git a/src/ce_editor.lfm b/src/ce_editor.lfm
index d31bf9fd..ca68c6fe 100644
--- a/src/ce_editor.lfm
+++ b/src/ce_editor.lfm
@@ -21,8 +21,8 @@ inherited CEEditorWidget: TCEEditorWidget
ClientWidth = 465
object editorStatus: TStatusBar[0]
Left = 0
- Height = 19
- Top = 377
+ Height = 21
+ Top = 375
Width = 465
BorderSpacing.Bottom = 2
Panels = <
diff --git a/src/ce_editor.pas b/src/ce_editor.pas
index a6fe4d75..b1a1ff21 100644
--- a/src/ce_editor.pas
+++ b/src/ce_editor.pas
@@ -214,7 +214,7 @@ begin
EntitiesConnector.addObserver(self);
//
fDetectModuleName := true;
- fname := getCoeditDocPath + optname;
+ fname := getDocPath + optname;
if fname.fileExists then
begin
loadFromFile(fname);
@@ -225,7 +225,7 @@ end;
destructor TCEPagesOptions.Destroy;
begin
- saveToFile(getCoeditDocPath + optname);
+ saveToFile(getDocPath + optname);
EntitiesConnector.removeObserver(self);
inherited;
end;
diff --git a/src/ce_editoroptions.pas b/src/ce_editoroptions.pas
index bb1c9c2a..f2151767 100644
--- a/src/ce_editoroptions.pas
+++ b/src/ce_editoroptions.pas
@@ -276,7 +276,7 @@ begin
ed := TSynEdit.Create(nil);
try
// note: cant use a TCESynMemo because it'd be added to the EntitiesConnector
- SetDefaultCoeditKeystrokes(ed);
+ SetDefaultDexedKeystrokes(ed);
for i:= 0 to ed.Keystrokes.Count-1 do
begin
shc := TCEPersistentShortcut(fShortCuts.Add);
@@ -462,14 +462,14 @@ begin
fBackup := TCEEditorOptionsBase.Create(self);
EntitiesConnector.addObserver(self);
//
- fname := getCoeditDocPath + edoptFname;
+ fname := getDocPath + edoptFname;
if fileExists(fname) then
loadFromFile(fname);
end;
destructor TCEEditorOptions.Destroy;
begin
- saveToFile(getCoeditDocPath + edoptFname);
+ saveToFile(getDocPath + edoptFname);
//
EntitiesConnector.removeObserver(self);
inherited;
@@ -488,7 +488,7 @@ begin
//
ed := TSynEdit.Create(nil);
try
- SetDefaultCoeditKeystrokes(ed);
+ SetDefaultDexedKeystrokes(ed);
// new version with more shortcuts
for i:= 0 to ed.Keystrokes.Count-1 do
begin
diff --git a/src/ce_gdb.lfm b/src/ce_gdb.lfm
index 7481900c..7c62cc72 100644
--- a/src/ce_gdb.lfm
+++ b/src/ce_gdb.lfm
@@ -21,31 +21,31 @@ inherited CEGdbWidget: TCEGdbWidget
ClientWidth = 517
object Panel1: TPanel[0]
Left = 0
- Height = 384
+ Height = 386
Top = 205
Width = 517
Align = alClient
AutoSize = True
BevelOuter = bvNone
- ClientHeight = 384
+ ClientHeight = 386
ClientWidth = 517
TabOrder = 0
object GroupBox3: TGroupBox
Left = 0
- Height = 178
+ Height = 180
Top = 206
Width = 517
Align = alClient
Caption = 'CPU'
- ClientHeight = 160
- ClientWidth = 515
+ ClientHeight = 161
+ ClientWidth = 513
TabOrder = 0
object cpuViewer: TTIPropertyGrid
Left = 0
- Height = 160
+ Height = 161
Hint = 'cpu registers'
Top = 0
- Width = 515
+ Width = 513
Align = alClient
CheckboxForBoolean = True
DefaultValueFont.Color = clWindowText
@@ -78,13 +78,13 @@ inherited CEGdbWidget: TCEGdbWidget
OnChange = PageControl2Change
object TabSheet3: TTabSheet
Caption = 'Variables'
- ClientHeight = 165
- ClientWidth = 511
+ ClientHeight = 173
+ ClientWidth = 515
object lstVariables: TListView
Left = 2
- Height = 136
- Top = 27
- Width = 507
+ Height = 140
+ Top = 31
+ Width = 511
Align = alClient
AutoWidthLastColumn = True
BorderSpacing.Around = 2
@@ -92,11 +92,11 @@ inherited CEGdbWidget: TCEGdbWidget
item
AutoSize = True
Caption = 'name'
- Width = 47
+ Width = 45
end
item
Caption = 'value'
- Width = 458
+ Width = 464
end>
GridLines = True
HideSelection = False
@@ -109,10 +109,10 @@ inherited CEGdbWidget: TCEGdbWidget
end
object varListFlt: TListViewFilterEdit
Left = 2
- Height = 23
+ Height = 27
Hint = 'locate variables'
Top = 2
- Width = 507
+ Width = 511
ButtonWidth = 24
NumGlyphs = 1
Align = alTop
@@ -124,8 +124,8 @@ inherited CEGdbWidget: TCEGdbWidget
end
object TabSheet4: TTabSheet
Caption = 'Assembler'
- ClientHeight = 165
- ClientWidth = 511
+ ClientHeight = 173
+ ClientWidth = 515
object lstAsm: TListView
Left = 2
Height = 161
@@ -139,11 +139,11 @@ inherited CEGdbWidget: TCEGdbWidget
item
AutoSize = True
Caption = 'address'
- Width = 61
+ Width = 59
end
item
Caption = 'instruction'
- Width = 444
+ Width = 446
end>
GridLines = True
HideSelection = False
@@ -158,19 +158,19 @@ inherited CEGdbWidget: TCEGdbWidget
end
object Panel3: TPanel[1]
Left = 4
- Height = 29
- Top = 593
+ Height = 27
+ Top = 595
Width = 509
Align = alBottom
AutoSize = True
BorderSpacing.Around = 4
BevelOuter = bvNone
- ClientHeight = 29
+ ClientHeight = 27
ClientWidth = 509
TabOrder = 1
object btnSendCom: TSpeedButton
Left = 504
- Height = 27
+ Height = 25
Top = 1
Width = 4
Align = alRight
@@ -180,7 +180,7 @@ inherited CEGdbWidget: TCEGdbWidget
end
object Edit1: TComboBox
Left = 0
- Height = 29
+ Height = 27
Hint = 'enter a custom GDB command or the program input with ">"'
Top = 0
Width = 503
@@ -214,14 +214,14 @@ inherited CEGdbWidget: TCEGdbWidget
TabOrder = 3
object TabSheet1: TTabSheet
Caption = 'Call stack'
- ClientHeight = 165
- ClientWidth = 511
+ ClientHeight = 173
+ ClientWidth = 515
object lstCallStack: TListView
Left = 0
- Height = 165
+ Height = 173
Hint = 'call stack'
Top = 0
- Width = 511
+ Width = 515
Align = alClient
AutoSort = False
Columns = <
@@ -251,8 +251,8 @@ inherited CEGdbWidget: TCEGdbWidget
end
object TabSheet2: TTabSheet
Caption = 'Thread list'
- ClientHeight = 165
- ClientWidth = 511
+ ClientHeight = 173
+ ClientWidth = 515
object lstThreads: TListView
Left = 0
Height = 169
@@ -266,36 +266,36 @@ inherited CEGdbWidget: TCEGdbWidget
item
AutoSize = True
Caption = 'id'
- Width = 22
+ Width = 20
end
item
AutoSize = True
Caption = 'state'
- Width = 43
+ Width = 41
end
item
AutoSize = True
Caption = 'core'
- Width = 38
+ Width = 36
end
item
AutoSize = True
Caption = 'function'
- Width = 63
- end
- item
- AutoSize = True
- Caption = 'address'
Width = 61
end
+ item
+ AutoSize = True
+ Caption = 'address'
+ Width = 59
+ end
item
AutoSize = True
Caption = 'filename'
- Width = 67
+ Width = 65
end
item
Caption = 'line'
- Width = 217
+ Width = 229
end>
GridLines = True
ReadOnly = True
@@ -307,8 +307,8 @@ inherited CEGdbWidget: TCEGdbWidget
end
object TabSheet5: TTabSheet
Caption = 'Debugee options'
- ClientHeight = 165
- ClientWidth = 511
+ ClientHeight = 173
+ ClientWidth = 515
object dbgeeOptsEd: TTIPropertyGrid
Left = 2
Height = 161
diff --git a/src/ce_gdb.pas b/src/ce_gdb.pas
index f2d7fe03..e0621acb 100644
--- a/src/ce_gdb.pas
+++ b/src/ce_gdb.pas
@@ -744,14 +744,14 @@ begin
fAutoGetCallStack:= true;
fAutoGetRegisters:= true;
fAutoGetVariables:= true;
- fname := getCoeditDocPath + optFname;
+ fname := getDocPath + optFname;
if fname.fileExists then
loadFromFile(fname);
end;
destructor TCEDebugOptions.destroy;
begin
- saveToFile(getCoeditDocPath + optFname);
+ saveToFile(getDocPath + optFname);
EntitiesConnector.removeObserver(self);
inherited;
end;
@@ -798,14 +798,14 @@ var
begin
Inherited;
fItems := TCollection.Create(TPersistentBreakPoint);
- fname := getCoeditDocPath + bpFname;
+ fname := getDocPath + bpFname;
if fname.fileExists then
loadFromFile(fname);
end;
destructor TPersistentBreakPoints.destroy;
begin
- saveToFile(getCoeditDocPath + bpFname);
+ saveToFile(getDocPath + bpFname);
fItems.Free;
inherited;
end;
@@ -1125,14 +1125,14 @@ var
begin
inherited create(AOwner);
fProjects := TCollection.Create(TCEDebugeeOption);
- fname := getCoeditDocPath + prjFname;
+ fname := getDocPath + prjFname;
if fname.fileExists then
loadFromFile(fname);
end;
destructor TCEDebugeeOptions.Destroy;
begin
- saveToFile(getCoeditDocPath + prjFname);
+ saveToFile(getDocPath + prjFname);
fProjects.Free;
inherited;
end;
diff --git a/src/ce_halstead.pas b/src/ce_halstead.pas
index 506e4ee0..5201cccc 100644
--- a/src/ce_halstead.pas
+++ b/src/ce_halstead.pas
@@ -116,7 +116,7 @@ var
begin
inherited;
fBackup:= THalsteadMetricsBase.create(self);
- f := getCoeditDocPath + optFname;
+ f := getDocPath + optFname;
if f.fileExists then
loadFromFile(f);
fBackup.assign(self);
@@ -126,7 +126,7 @@ end;
destructor THalsteadMetrics.destroy;
begin
EntitiesConnector.removeObserver(self);
- saveTofile(getCoeditDocPath + optFname);
+ saveTofile(getDocPath + optFname);
inherited;
end;
diff --git a/src/ce_infos.lfm b/src/ce_infos.lfm
index 484ff9bf..b07c448c 100644
--- a/src/ce_infos.lfm
+++ b/src/ce_infos.lfm
@@ -22,7 +22,7 @@ inherited CEInfoWidget: TCEInfoWidget
ClientWidth = 296
object GroupBox1: TGroupBox[0]
Left = 4
- Height = 77
+ Height = 78
Top = 4
Width = 288
Align = alTop
@@ -30,13 +30,13 @@ inherited CEInfoWidget: TCEInfoWidget
BorderSpacing.Around = 4
Caption = 'about'
ClientHeight = 59
- ClientWidth = 286
+ ClientWidth = 284
TabOrder = 0
object Label1: TLabel
Left = 8
Height = 1
Top = 8
- Width = 270
+ Width = 268
Align = alTop
Alignment = taCenter
BorderSpacing.Around = 8
@@ -49,7 +49,7 @@ inherited CEInfoWidget: TCEInfoWidget
Left = 8
Height = 34
Top = 17
- Width = 270
+ Width = 268
Align = alClient
Alignment = taCenter
BorderSpacing.Around = 8
@@ -62,21 +62,21 @@ inherited CEInfoWidget: TCEInfoWidget
end
object GroupBox2: TGroupBox[1]
Left = 4
- Height = 22
- Top = 85
+ Height = 21
+ Top = 86
Width = 288
Align = alClient
AutoSize = True
BorderSpacing.Around = 4
Caption = 'tools status'
- ClientHeight = 4
- ClientWidth = 286
+ ClientHeight = 2
+ ClientWidth = 284
TabOrder = 1
object boxTools: TScrollBox
Left = 4
Height = 1
- Top = 2
- Width = 278
+ Top = 1
+ Width = 276
HorzScrollBar.Page = 1
VertScrollBar.Page = 1
Align = alClient
diff --git a/src/ce_infos.pas b/src/ce_infos.pas
index 59e39bcf..b279997a 100644
--- a/src/ce_infos.pas
+++ b/src/ce_infos.pas
@@ -215,7 +215,7 @@ begin
try
len := read(ver[1], ver.length);
setLength(ver, len);
- Label1.Caption := 'Coedit - ' + ver[1..ver.length];
+ Label1.Caption := 'dexed - ' + ver[1..ver.length];
finally
free;
end;
diff --git a/src/ce_interfaces.pas b/src/ce_interfaces.pas
index 92ec8915..f4fa09f6 100644
--- a/src/ce_interfaces.pas
+++ b/src/ce_interfaces.pas
@@ -351,7 +351,7 @@ type
(**
- * Single service related to the expansion of Coedit "symbolic strings".
+ * Single service related to the expansion of "symbolic strings".
*)
ICESymStringExpander = interface(ICESingleService)
// expands all the symbols of value in result.
diff --git a/src/ce_libman.pas b/src/ce_libman.pas
index de8be3cf..61f796df 100644
--- a/src/ce_libman.pas
+++ b/src/ce_libman.pas
@@ -82,7 +82,7 @@ type
TLibraryList = specialize TObjectHashSet;
(**
- * Represents all the D libraries handled by Coedit.
+ * Represents all the D libraries handled by Dexed.
*)
TLibraryManager = class(TWritableLfmTextComponent, IFPObserver)
type
@@ -330,7 +330,7 @@ begin
fItemsByAlias := TItemsByAlias.create;
fCollection := TCollection.Create(TLibraryItem);
fCollection.FPOAttachObserver(self);
- nme := getCoeditDocPath + libFname;
+ nme := getDocPath + libFname;
if nme.fileExists then
loadFromFile(nme);
for i := fCollection.Count-1 downto 0 do
@@ -351,8 +351,8 @@ end;
destructor TLibraryManager.destroy;
begin
- ForceDirectoriesUTF8(getCoeditDocPath);
- LibMan.saveToFile(getCoeditDocPath + libFname);
+ ForceDirectoriesUTF8(getDocPath);
+ LibMan.saveToFile(getDocPath + libFname);
fItemsByAlias.Free;
fCollection.Free;
inherited;
diff --git a/src/ce_main.lfm b/src/ce_main.lfm
index 76898de6..0b3ef62a 100644
--- a/src/ce_main.lfm
+++ b/src/ce_main.lfm
@@ -1472,6 +1472,7 @@ object CEMainForm: TCEMainForm
OnResize = FormResize
OnWindowStateChange = FormWindowStateChange
ShowHint = True
+ LCLVersion = '1.8.4.0'
Visible = False
object mainMenu: TMainMenu
top = 1
@@ -1857,7 +1858,7 @@ object CEMainForm: TCEMainForm
object mnuItemHelp: TMenuItem
Caption = 'Help'
object mnuItemAbout: TMenuItem
- Caption = 'About Coedit and tools information'
+ Caption = 'About dexed and tools information'
OnClick = mnuItemAboutClick
end
object mnuItemCheckUpd: TMenuItem
diff --git a/src/ce_main.pas b/src/ce_main.pas
index 936f5750..9eeb1469 100644
--- a/src/ce_main.pas
+++ b/src/ce_main.pas
@@ -393,7 +393,7 @@ type
fCovModUt: boolean;
fDscanUnittests: boolean;
fDoc: TCESynMemo;
- fFirstTimeCoedit: boolean;
+ fFirstTimeRun: boolean;
fMultidoc: ICEMultiDocHandler;
fScCollectCount: Integer;
fUpdateCount: NativeInt;
@@ -1697,7 +1697,7 @@ begin
end;
// load existing or default docking
- if not reset and FileExists(getCoeditDocPath + 'docking.xml') then
+ if not reset and FileExists(getDocPath + 'docking.xml') then
begin
// load later (https://bugs.freepascal.org/view.php?id=29475)
end
@@ -1781,7 +1781,7 @@ var
fname: string;
begin
// project and files MRU
- fname := getCoeditDocPath + 'mostrecent.txt';
+ fname := getDocPath + 'mostrecent.txt';
if fname.fileExists then with TCEPersistentMainMrus.create(nil) do
try
setTargets(fFileMru, fProjMru, fPrjGrpMru);
@@ -1790,7 +1790,7 @@ begin
Free;
end;
// shortcuts for the actions standing in the main action list
- fname := getCoeditDocPath + 'mainshortcuts.txt';
+ fname := getDocPath + 'mainshortcuts.txt';
if fname.fileExists then with TCEPersistentMainShortcuts.create(nil) do
try
loadFromFile(fname);
@@ -1800,18 +1800,18 @@ begin
end;
// runnables opts
fRunnablesOptions := TCEEditableRunnableOptions.create(self);
- fname := getCoeditDocPath + 'runnables.txt';
+ fname := getDocPath + 'runnables.txt';
if fname.fileExists then
fRunnablesOptions.loadFromFile(fname);
// globals opts
fAppliOpts := TCEApplicationOptions.Create(self);
- fname := getCoeditDocPath + 'application.txt';
+ fname := getDocPath + 'application.txt';
if fname.fileExists then
begin
fAppliOpts.loadFromFile(fname);
fAppliOpts.assignTo(self);
end
- else fFirstTimeCoedit := true;
+ else fFirstTimeRun := true;
end;
procedure TCEMainForm.SaveSettings;
@@ -1822,7 +1822,7 @@ begin
with TCEPersistentMainMrus.create(nil) do
try
setTargets(fFileMru, fProjMru, fPrjGrpMru);
- saveToFile(getCoeditDocPath + 'mostrecent.txt');
+ saveToFile(getDocPath + 'mostrecent.txt');
finally
Free;
end;
@@ -1830,15 +1830,15 @@ begin
with TCEPersistentMainShortcuts.create(nil) do
try
assign(self);
- saveToFile(getCoeditDocPath + 'mainshortcuts.txt');
+ saveToFile(getDocPath + 'mainshortcuts.txt');
finally
Free;
end;
// globals opts
fAppliOpts.assign(self);
- fAppliOpts.saveToFile(getCoeditDocPath + 'application.txt');
+ fAppliOpts.saveToFile(getDocPath + 'application.txt');
// runnables opts
- fRunnablesOptions.saveToFile(getCoeditDocPath + 'runnables.txt');
+ fRunnablesOptions.saveToFile(getDocPath + 'runnables.txt');
end;
procedure TCEMainForm.SaveDocking;
@@ -1861,19 +1861,19 @@ begin
DockMaster.GetAnchorSite(fWidgList.widget[i]).Close;
end;
- forceDirectory(getCoeditDocPath);
- xcfg := TXMLConfigStorage.Create(getCoeditDocPath + 'docking.xml.tmp', false);
+ forceDirectory(getDocPath);
+ xcfg := TXMLConfigStorage.Create(getDocPath + 'docking.xml.tmp', false);
try
DockMaster.SaveLayoutToConfig(xcfg);
xcfg.WriteToDisk;
// TODO-cdocking: remove this when AnchorDocking wont save anymore invalid layout
with TMemoryStream.Create do
try
- LoadFromFile(getCoeditDocPath + 'docking.xml.tmp');
+ LoadFromFile(getDocPath + 'docking.xml.tmp');
if Size < 10000 then
begin
- SaveToFile(getCoeditDocPath + 'docking.xml');
- SysUtils.DeleteFile(getCoeditDocPath + 'docking.xml.tmp');
+ SaveToFile(getDocPath + 'docking.xml');
+ SysUtils.DeleteFile(getDocPath + 'docking.xml.tmp');
end;
finally
free;
@@ -1882,7 +1882,7 @@ begin
xcfg.Free;
end;
- xcfg := TXMLConfigStorage.Create(getCoeditDocPath + 'dockingopts.xml',false);
+ xcfg := TXMLConfigStorage.Create(getDocPath + 'dockingopts.xml',false);
try
DockMaster.SaveSettingsToConfig(xcfg);
xcfg.WriteToDisk;
@@ -1897,9 +1897,9 @@ var
str: TMemoryStream;
begin
result := false;
- if fileExists(getCoeditDocPath + 'docking.xml') then
+ if fileExists(getDocPath + 'docking.xml') then
begin
- xcfg := TXMLConfigStorage.Create(getCoeditDocPath + 'docking.xml', true);
+ xcfg := TXMLConfigStorage.Create(getDocPath + 'docking.xml', true);
try
try
DockMaster.LoadLayoutFromConfig(xcfg, false);
@@ -1909,7 +1909,7 @@ begin
str := TMemoryStream.Create;
try
xcfg.SaveToStream(str);
- str.saveToFile(getCoeditDocPath + 'docking.bak')
+ str.saveToFile(getDocPath + 'docking.bak')
finally
str.Free;
end;
@@ -1917,9 +1917,9 @@ begin
xcfg.Free;
end;
end;
- if fileExists(getCoeditDocPath + 'dockingopts.xml') then
+ if fileExists(getDocPath + 'dockingopts.xml') then
begin
- xcfg := TXMLConfigStorage.Create(getCoeditDocPath + 'dockingopts.xml', true);
+ xcfg := TXMLConfigStorage.Create(getDocPath + 'dockingopts.xml', true);
try
try
DockMaster.LoadSettingsFromConfig(xcfg);
@@ -1929,7 +1929,7 @@ begin
str := TMemoryStream.Create;
try
xcfg.SaveToStream(str);
- str.saveToFile(getCoeditDocPath + 'dockingopts.bak')
+ str.saveToFile(getDocPath + 'dockingopts.bak')
finally
str.Free;
end;
@@ -1964,7 +1964,7 @@ begin
with TCELastDocsAndProjs.create(nil) do
try
assign(self);
- saveToFile(getCoeditDocPath + 'lastdocsandproj.txt');
+ saveToFile(getDocPath + 'lastdocsandproj.txt');
finally
free;
end;
@@ -1974,7 +1974,7 @@ procedure TCEMainForm.LoadLastDocsAndProj;
var
str: string;
begin
- str := getCoeditDocPath + 'lastdocsandproj.txt';
+ str := getDocPath + 'lastdocsandproj.txt';
if str.fileExists then
with TCELastDocsAndProjs.create(nil) do
try
@@ -1987,7 +1987,7 @@ end;
function checkForUpdate: string;
const
- updURL = 'https://api.github.com/repos/BBasile/Coedit/releases/latest';
+ updURL = 'https://api.github.com/repos/BBasile/dexed/releases/latest';
var
prs: TJSONParser = nil;
dat: TJSONData = nil;
@@ -2078,7 +2078,7 @@ begin
DockMaster.ResetSplitters;
setSplitterWheelEvent;
- if fFirstTimeCoedit then
+ if fFirstTimeRun then
begin
actFileNewRun.Execute;
if fInfoWidg.hasMissingTools then
@@ -2087,7 +2087,7 @@ begin
// see https://bugs.freepascal.org/view.php?id=29475
// reloading must be done here otherwise there are "jumps"
- if FileExists(getCoeditDocPath + 'docking.xml') then
+ if FileExists(getDocPath + 'docking.xml') then
LoadDocking();
if fAppliOpts.autoCheckUpdates then
@@ -2142,7 +2142,7 @@ end;
procedure TCEMainForm.mnuItemManualClick(Sender: TObject);
begin
- OpenURL('https://bbasile.github.io/Coedit/');
+ OpenURL('https://bbasile.github.io/dexed/');
end;
destructor TCEMainForm.destroy;
@@ -2164,7 +2164,7 @@ end;
procedure TCEMainForm.UpdateDockCaption(Exclude: TControl = nil);
begin
// otherwise dockmaster puts the widget list.
- Caption := 'Coedit';
+ Caption := 'dexed';
end;
procedure TCEMainForm.ApplicationProperties1Exception(Sender: TObject;E: Exception);
@@ -2679,7 +2679,7 @@ begin
LineEnding +
'void main(string[] args)' + LineEnding +
'{' + LineEnding +
- body[fFirstTimeCoedit] +
+ body[fFirstTimeRun] +
'}';
fDoc.setFocus;
end;
@@ -3100,7 +3100,7 @@ begin
end
else
begin
- // back compat, see https://github.com/BBasile/Coedit/issues/276
+ // back compat, see https://github.com/BBasile/dexed/issues/276
dmdproc.Parameters.Add('-version=runnable_module');
dmdproc.Parameters.Add('-version=run_single_module');
@@ -3623,7 +3623,7 @@ begin
lst := TStringList.Create;
try
- listFiles(lst, getCoeditDocPath + 'layouts' + DirectorySeparator);
+ listFiles(lst, getDocPath + 'layouts' + DirectorySeparator);
for i := 0 to lst.Count-1 do
begin
itm := TMenuItem.Create(self);
@@ -3640,7 +3640,7 @@ end;
procedure TCEMainForm.layoutMnuItemClick(sender: TObject);
begin
- layoutLoadFromFile(getCoeditDocPath + 'layouts' + DirectorySeparator +
+ layoutLoadFromFile(getDocPath + 'layouts' + DirectorySeparator +
TMenuItem(sender).Caption + '.xml');
end;
@@ -3655,7 +3655,7 @@ begin
if fname.extractFileExt <> '.xml' then
fname += '.xml';
- layoutSaveToFile(getCoeditDocPath + 'layouts' + DirectorySeparator + fname);
+ layoutSaveToFile(getDocPath + 'layouts' + DirectorySeparator + fname);
layoutUpdateMenu;
end;
@@ -3717,9 +3717,9 @@ end;
procedure TCEMainForm.showProjTitle;
begin
if assigned(fProject) and fProject.filename.fileExists then
- caption := format('Coedit - %s', [shortenPath(fProject.filename, 30)])
+ caption := format('dexed - %s', [shortenPath(fProject.filename, 30)])
else
- caption := 'Coedit';
+ caption := 'dexed';
end;
procedure TCEMainForm.saveProjSource(const document: TCESynMemo);
diff --git a/src/ce_messages.pas b/src/ce_messages.pas
index 6c63e5b4..556a7fb1 100644
--- a/src/ce_messages.pas
+++ b/src/ce_messages.pas
@@ -447,7 +447,7 @@ begin
fEditorMessagePos := TCEEditorMessagePos.Create;
- fname := getCoeditDocPath + optname;
+ fname := getDocPath + optname;
if fname.fileExists then
begin
fOptions.loadFromFile(fname);
@@ -461,7 +461,7 @@ end;
destructor TCEMessagesWidget.destroy;
begin
fEditorMessagePos.Free;
- fOptions.saveToFile(getCoeditDocPath + optname);
+ fOptions.saveToFile(getDocPath + optname);
EntitiesConnector.removeObserver(self);
inherited;
end;
@@ -1027,7 +1027,7 @@ begin
if not openFileFromDmdMessage(msg) then
exit;
- // fixes strange bug : https://github.com/BBasile/Coedit/issues/320
+ // fixes strange bug : https://github.com/BBasile/dexed/issues/320
if (fDoc <> old) and fOptions.singleMessageClick and
assigned(dat) and (dat^.ctxt = amcEdit) then
List.ClearSelection(false);
diff --git a/src/ce_miniexplorer.pas b/src/ce_miniexplorer.pas
index 4c45903e..365b9b58 100644
--- a/src/ce_miniexplorer.pas
+++ b/src/ce_miniexplorer.pas
@@ -356,7 +356,7 @@ begin
treeSetRoots;
- fname := getCoeditDocPath + OptsFname;
+ fname := getDocPath + OptsFname;
if fname.fileExists then
with TCEMiniExplorerOptions.create(nil) do
try
@@ -378,7 +378,7 @@ begin
with TCEMiniExplorerOptions.create(nil) do
try
assign(self);
- saveToFile(getCoeditDocPath + OptsFname);
+ saveToFile(getDocPath + OptsFname);
finally
free;
end;
diff --git a/src/ce_observer.pas b/src/ce_observer.pas
index d7a083e9..e6fd2441 100644
--- a/src/ce_observer.pas
+++ b/src/ce_observer.pas
@@ -10,7 +10,7 @@ uses
type
(**
- * interface for a single Coedit service (many to one relation).
+ * interface for a single service (many to one relation).
* A service is valid during the whole application life-time and
* is mostly designed to avoid messy uses clauses or to limit
* the visibility of the implementer methods.
@@ -57,7 +57,7 @@ type
end;
(**
- * Interface for a Coedit subject. Basically designed to hold a list of observer
+ * Interface for a subject. Basically designed to hold a list of observer
*)
ICESubject = interface
// an observer is proposed. anObserver is not necessarly compatible.
diff --git a/src/ce_processes.pas b/src/ce_processes.pas
index 850a942d..5a114c7f 100644
--- a/src/ce_processes.pas
+++ b/src/ce_processes.pas
@@ -10,7 +10,7 @@ uses
type
{
- The stanndard process wrapper used in Coedit.
+ The standard process wrapper that used accross the applicaton.
This class solves several issues encountered when using TProcess and TAsyncProcess:
diff --git a/src/ce_procinput.lfm b/src/ce_procinput.lfm
index 8aed9f01..745680a4 100644
--- a/src/ce_procinput.lfm
+++ b/src/ce_procinput.lfm
@@ -13,6 +13,7 @@ inherited CEProcInputWidget: TCEProcInputWidget
ClientWidth = 558
inherited Content: TPanel
Height = 71
+ Top = 36
Width = 558
ClientHeight = 71
ClientWidth = 558
@@ -31,20 +32,20 @@ inherited CEProcInputWidget: TCEProcInputWidget
end
object Panel1: TPanel[1]
Left = 4
- Height = 31
+ Height = 33
Top = 29
Width = 550
Align = alTop
AutoSize = True
BorderSpacing.Around = 4
BevelOuter = bvNone
- ClientHeight = 31
+ ClientHeight = 33
ClientWidth = 550
Enabled = False
TabOrder = 1
object txtInp: TEdit
Left = 0
- Height = 25
+ Height = 27
Top = 3
Width = 530
Align = alClient
@@ -55,7 +56,7 @@ inherited CEProcInputWidget: TCEProcInputWidget
end
object btnClose: TSpeedButton
Left = 538
- Height = 27
+ Height = 29
Hint = 'close standard input'
Top = 2
Width = 4
@@ -66,7 +67,7 @@ inherited CEProcInputWidget: TCEProcInputWidget
end
object btnKill: TSpeedButton
Left = 544
- Height = 27
+ Height = 29
Hint = 'kill process'
Top = 2
Width = 4
@@ -77,7 +78,7 @@ inherited CEProcInputWidget: TCEProcInputWidget
end
object btnSend: TSpeedButton
Left = 532
- Height = 27
+ Height = 29
Hint = 'write content to standard input'
Top = 2
Width = 4
diff --git a/src/ce_procinput.pas b/src/ce_procinput.pas
index 3754c066..b0b86088 100644
--- a/src/ce_procinput.pas
+++ b/src/ce_procinput.pas
@@ -61,7 +61,7 @@ begin
fMru := TCEMRUList.Create;
fMru.maxCount := 25;
EntitiesConnector.addSingleService(self);
- fname := getCoeditDocPath + OptsFname;
+ fname := getDocPath + OptsFname;
if OptsFname.fileExists then
fMru.LoadFromFile(fname);
if fMru.Count = 0 then
@@ -94,7 +94,7 @@ end;
destructor TCEProcInputWidget.destroy;
begin
// note that mru list max count is not saved.
- fMru.SaveToFile(getCoeditDocPath + OptsFname);
+ fMru.SaveToFile(getDocPath + OptsFname);
fMru.Free;
inherited;
end;
diff --git a/src/ce_profileviewer.lfm b/src/ce_profileviewer.lfm
index 0e40ca86..05d09177 100644
--- a/src/ce_profileviewer.lfm
+++ b/src/ce_profileviewer.lfm
@@ -35,27 +35,27 @@ inherited CEProfileViewerWidget: TCEProfileViewerWidget
item
AutoSize = True
Caption = 'Num calls'
- Width = 75
- end
- item
- AutoSize = True
- Caption = 'Tree time'
- Width = 71
- end
- item
- AutoSize = True
- Caption = 'Func time'
Width = 73
end
+ item
+ AutoSize = True
+ Caption = 'Tree time'
+ Width = 69
+ end
+ item
+ AutoSize = True
+ Caption = 'Func time'
+ Width = 71
+ end
item
AutoSize = True
Caption = 'Per call'
- Width = 58
+ Width = 56
end
item
AutoSize = True
Caption = 'function'
- Width = 246
+ Width = 254
end>
HideSelection = False
ReadOnly = True
@@ -165,7 +165,7 @@ inherited CEProfileViewerWidget: TCEProfileViewerWidget
end
object selPieSource: TComboBox[3]
Left = 118
- Height = 33
+ Height = 31
Hint = 'select the pie representation'
Top = 0
Width = 282
diff --git a/src/ce_profileviewer.pas b/src/ce_profileviewer.pas
index 58b2cfe4..a85042ef 100644
--- a/src/ce_profileviewer.pas
+++ b/src/ce_profileviewer.pas
@@ -135,14 +135,14 @@ begin
inherited create(aOwner);
fBackup := TCEProfileViewerOptionsBase.create(nil);
EntitiesConnector.addObserver(self);
- s := getCoeditDocPath + optFname;
+ s := getDocPath + optFname;
if s.fileExists then
loadFromFile(s);
end;
destructor TCEprofileViewerOptions.destroy;
begin
- saveTofile(getCoeditDocPath + optFname);
+ saveTofile(getDocPath + optFname);
EntitiesConnector.removeObserver(self);
fBackup.free;
inherited;
diff --git a/src/ce_projinspect.pas b/src/ce_projinspect.pas
index b2f2f045..8431e6bd 100644
--- a/src/ce_projinspect.pas
+++ b/src/ce_projinspect.pas
@@ -165,7 +165,7 @@ begin
TreeFilterEdit1.BorderSpacing.Left := ScaleX(filterAlign[false], 96);
toolbarResize(nil);
- fname := getCoeditDocPath + optFname;
+ fname := getDocPath + optFname;
if fname.fileExists then
begin
with TCEProjectInspectorOptions.Create(nil) do
@@ -186,7 +186,7 @@ begin
with TCEProjectInspectorOptions.Create(nil) do
try
fileListAsTree:= self.fileListAsTree;
- saveToFile(getCoeditDocPath + optFname);
+ saveToFile(getDocPath + optFname);
finally
free;
end;
diff --git a/src/ce_search.lfm b/src/ce_search.lfm
index b7d325d2..01fbd7ca 100644
--- a/src/ce_search.lfm
+++ b/src/ce_search.lfm
@@ -19,7 +19,7 @@ inherited CESearchWidget: TCESearchWidget
ClientWidth = 422
object cbToFind: TComboBox[0]
Left = 4
- Height = 29
+ Height = 27
Top = 4
Width = 414
Align = alTop
@@ -34,8 +34,8 @@ inherited CESearchWidget: TCESearchWidget
end
object btnFind: TBitBtn[1]
Left = 4
- Height = 29
- Top = 161
+ Height = 27
+ Top = 169
Width = 414
Align = alBottom
AutoSize = True
@@ -45,8 +45,8 @@ inherited CESearchWidget: TCESearchWidget
end
object btnReplace: TBitBtn[2]
Left = 4
- Height = 29
- Top = 227
+ Height = 27
+ Top = 231
Width = 414
Align = alBottom
AutoSize = True
@@ -56,21 +56,21 @@ inherited CESearchWidget: TCESearchWidget
end
object grpOpts: TGroupBox[3]
Left = 4
- Height = 87
- Top = 70
+ Height = 99
+ Top = 66
Width = 414
Align = alClient
AutoSize = True
BorderSpacing.Around = 4
Caption = 'Options'
- ClientHeight = 69
- ClientWidth = 412
+ ClientHeight = 80
+ ClientWidth = 410
TabOrder = 4
object FlowPanel1: TFlowPanel
Left = 0
- Height = 69
+ Height = 80
Top = 0
- Width = 412
+ Width = 410
Align = alClient
AutoSize = True
BevelOuter = bvNone
@@ -110,9 +110,9 @@ inherited CESearchWidget: TCESearchWidget
TabOrder = 0
object chkRegex: TCheckBox
Left = 0
- Height = 22
+ Height = 20
Top = 0
- Width = 100
+ Width = 98
Anchors = []
Caption = 'allow regex'
Checked = True
@@ -121,27 +121,27 @@ inherited CESearchWidget: TCESearchWidget
end
object chkPrompt: TCheckBox
Left = 0
- Height = 22
- Top = 23
- Width = 71
+ Height = 20
+ Top = 21
+ Width = 69
Anchors = []
Caption = 'prompt'
TabOrder = 1
end
object chkCaseSens: TCheckBox
Left = 0
- Height = 22
- Top = 46
- Width = 117
+ Height = 20
+ Top = 42
+ Width = 115
Anchors = []
Caption = 'case sensitive'
TabOrder = 2
end
object chkFromCur: TCheckBox
- Left = 117
- Height = 22
+ Left = 115
+ Height = 20
Top = 0
- Width = 99
+ Width = 97
Anchors = []
Caption = 'from cursor'
Checked = True
@@ -149,19 +149,19 @@ inherited CESearchWidget: TCESearchWidget
TabOrder = 3
end
object chkBack: TCheckBox
- Left = 117
- Height = 22
- Top = 23
- Width = 87
+ Left = 115
+ Height = 20
+ Top = 21
+ Width = 85
Anchors = []
Caption = 'backward'
TabOrder = 4
end
object chkWWord: TCheckBox
- Left = 117
- Height = 22
- Top = 46
- Width = 99
+ Left = 115
+ Height = 20
+ Top = 42
+ Width = 97
Anchors = []
Caption = 'whole word'
Checked = True
@@ -172,8 +172,8 @@ inherited CESearchWidget: TCESearchWidget
end
object btnReplaceAll: TBitBtn[4]
Left = 4
- Height = 29
- Top = 260
+ Height = 27
+ Top = 262
Width = 414
Align = alBottom
AutoSize = True
@@ -183,21 +183,21 @@ inherited CESearchWidget: TCESearchWidget
end
object Panel1: TPanel[5]
Left = 4
- Height = 29
- Top = 37
+ Height = 27
+ Top = 35
Width = 414
Align = alTop
AutoSize = True
BorderSpacing.Around = 4
BevelOuter = bvNone
- ClientHeight = 29
+ ClientHeight = 27
ClientWidth = 414
TabOrder = 5
object cbReplaceWth: TComboBox
- Left = 111
- Height = 29
+ Left = 109
+ Height = 27
Top = 0
- Width = 303
+ Width = 305
Align = alClient
AutoComplete = True
AutoCompleteText = [cbactEnabled, cbactEndOfLineComplete, cbactSearchCaseSensitive, cbactSearchAscending]
@@ -209,9 +209,9 @@ inherited CESearchWidget: TCESearchWidget
end
object chkEnableRep: TCheckBox
Left = 0
- Height = 29
+ Height = 27
Top = 0
- Width = 111
+ Width = 109
Align = alLeft
Caption = 'Replace with '
OnChange = chkEnableRepChange
@@ -220,31 +220,31 @@ inherited CESearchWidget: TCESearchWidget
end
object Panel2: TPanel[6]
Left = 4
- Height = 29
- Top = 194
+ Height = 27
+ Top = 200
Width = 414
Align = alBottom
AutoSize = True
BorderSpacing.Around = 4
BevelOuter = bvNone
- ClientHeight = 29
+ ClientHeight = 27
ClientWidth = 414
TabOrder = 6
object btnFindAll: TBitBtn
Left = 0
- Height = 29
+ Height = 27
Top = 0
- Width = 400
+ Width = 402
Align = alClient
AutoSize = True
Caption = 'btnFindAll'
TabOrder = 0
end
object btnAllScope: TBitBtn
- Left = 402
- Height = 29
+ Left = 404
+ Height = 27
Top = 0
- Width = 12
+ Width = 10
Align = alRight
AutoSize = True
BorderSpacing.Left = 2
diff --git a/src/ce_search.pas b/src/ce_search.pas
index 70a963ab..8cbca05f 100644
--- a/src/ce_search.pas
+++ b/src/ce_search.pas
@@ -234,7 +234,7 @@ begin
fSearchMru := TCEMruList.Create;
fReplaceMru:= TCEMruList.Create;
- fname := getCoeditDocPath + OptsFname;
+ fname := getDocPath + OptsFname;
if fname.fileExists then with TCESearchOptions.create(nil) do
try
loadFromFile(fname);
@@ -284,7 +284,7 @@ begin
with TCESearchOptions.create(nil) do
try
assign(self);
- saveToFile(getCoeditDocPath + OptsFname);
+ saveToFile(getDocPath + OptsFname);
finally
free;
end;
@@ -311,7 +311,7 @@ function dlgReplaceAll: TModalResult;
const
Btns = [mbYes, mbNo, mbYesToAll, mbNoToAll];
begin
- exit( MessageDlg('Coedit', 'Replace this match ?', mtConfirmation, Btns, ''));
+ exit( MessageDlg('dexed', 'Replace this match ?', mtConfirmation, Btns, ''));
end;
procedure TCESearchWidget.replaceEvent(Sender: TObject; const ASearch, AReplace:
diff --git a/src/ce_symlist.pas b/src/ce_symlist.pas
index f247575b..79586e23 100644
--- a/src/ce_symlist.pas
+++ b/src/ce_symlist.pas
@@ -418,7 +418,7 @@ begin
TreeFilterEdit1.BorderSpacing.Left:= ScaleX(30,96);
fOptions := TCESymbolListOptions.Create(self);
fOptions.Name:= 'symbolListOptions';
- fname := getCoeditDocPath + OptsFname;
+ fname := getDocPath + OptsFname;
if fname.fileExists then
fOptions.loadFromFile(fname);
fOptions.AssignTo(self);
@@ -451,7 +451,7 @@ begin
killProcess(fToolProc);
fSyms.Free;
- fOptions.saveToFile(getCoeditDocPath + OptsFname);
+ fOptions.saveToFile(getDocPath + OptsFname);
fOptions.Free;
inherited;
diff --git a/src/ce_symstring.pas b/src/ce_symstring.pas
index d7b91309..e8b22f43 100644
--- a/src/ce_symstring.pas
+++ b/src/ce_symstring.pas
@@ -23,7 +23,7 @@ const
type
(**
- * TCESymbolExpander is designed to expand Coedit symbolic strings,
+ * TCESymbolExpander is designed to expand symbolic strings,
* using the information collected from several observer interfaces.
*)
TCESymbolExpander = class(ICEDocumentObserver, ICEProjectObserver, ICESymStringExpander, ICEMiniExplorerObserver)
@@ -295,8 +295,8 @@ begin
'ENV_TEMP': Result += fSymbols[ENV_TEMP];
'ENV_USER': Result += fSymbols[ENV_USER];
//
- 'CAF', 'CoeditApplicationFile': Result += fSymbols[CAF];
- 'CAP', 'CoeditApplicationPath': Result += fSymbols[CAP];
+ 'AF', 'CAF', 'CoeditApplicationFile': Result += fSymbols[CAF];
+ 'AP', 'CAP', 'CoeditApplicationPath': Result += fSymbols[CAP];
'MEP', 'MiniExplorerPath': Result += fSymbols[MEP];
//
'CFF', 'CurrentFileFile' : Result += fSymbols[CFF];
diff --git a/src/ce_synmemo.pas b/src/ce_synmemo.pas
index 92b41a12..7b0c40b7 100644
--- a/src/ce_synmemo.pas
+++ b/src/ce_synmemo.pas
@@ -426,7 +426,7 @@ type
constructor construct(numSpaces, numTabs: integer);
end;
- procedure SetDefaultCoeditKeystrokes(ed: TSynEdit);
+ procedure SetDefaultDexedKeystrokes(ed: TSynEdit);
function CustomStringToCommand(const Ident: string; var Int: Longint): Boolean;
function CustomCommandToSstring(Int: Longint; var Ident: string): Boolean;
@@ -820,7 +820,7 @@ begin
if (tempn = fMemo.tempFilename) or (not tempn.fileExists) then
exit;
- fname := getCoeditDocPath + 'editorcache' + DirectorySeparator;
+ fname := getDocPath + 'editorcache' + DirectorySeparator;
ForceDirectories(fname);
chksm := crc32(0, nil, 0);
chksm := crc32(chksm, @tempn[1], tempn.length);
@@ -838,7 +838,7 @@ begin
if not tempn.fileExists then
exit;
- fname := getCoeditDocPath + 'editorcache' + DirectorySeparator;
+ fname := getDocPath + 'editorcache' + DirectorySeparator;
chksm := crc32(0, nil, 0);
chksm := crc32(chksm, @tempn[1], tempn.length);
fname := fname + format('%.8X.txt', [chksm]);
@@ -1004,7 +1004,7 @@ begin
OnStatusChange:= @handleStatusChanged;
fDefaultFontSize := 10;
Font.Size:=10;
- SetDefaultCoeditKeystrokes(Self); // not called in inherited if owner = nil !
+ SetDefaultDexedKeystrokes(Self); // not called in inherited if owner = nil !
fLexToks:= TLexTokenList.Create;
fSmartDdocNewline := true;
@@ -1276,7 +1276,7 @@ end;
{$ENDREGION --------------------------------------------------------------------}
{$REGION Custom editor commands and shortcuts ----------------------------------}
-procedure SetDefaultCoeditKeystrokes(ed: TSynEdit);
+procedure SetDefaultDexedKeystrokes(ed: TSynEdit);
begin
with ed do
begin
@@ -3023,7 +3023,7 @@ begin
end;
{$ENDREGION --------------------------------------------------------------------}
-{$REGION Coedit memo things ----------------------------------------------------}
+{$REGION memo things -----------------------------------------------------------}
procedure TCESynMemo.handleStatusChanged(Sender: TObject; Changes: TSynStatusChanges);
begin
if scOptions in Changes then
@@ -3313,7 +3313,7 @@ var
begin
lst := TStringList.Create;
try
- listFiles(lst, getCoeditDocPath + 'editorcache' + DirectorySeparator);
+ listFiles(lst, getDocPath + 'editorcache' + DirectorySeparator);
today := date();
for fname in lst do if FileAge(fname, t) then
begin
diff --git a/src/ce_term.pas b/src/ce_term.pas
index c6c6cfd0..c0fa983e 100644
--- a/src/ce_term.pas
+++ b/src/ce_term.pas
@@ -212,7 +212,7 @@ begin
fOpts:= TCETerminalOptions.Create(self);
- f := getCoeditDocPath + optFname;
+ f := getDocPath + optFname;
if f.fileExists then
fOpts.loadFromFile(f);
@@ -221,7 +221,7 @@ end;
destructor TCETermWidget.destroy;
begin
- fOpts.saveToFile(getCoeditDocPath + optFname);
+ fOpts.saveToFile(getDocPath + optFname);
EntitiesConnector.removeObserver(fOpts);
inherited;
end;
diff --git a/src/ce_todolist.lfm b/src/ce_todolist.lfm
index f638267c..49e8575c 100644
--- a/src/ce_todolist.lfm
+++ b/src/ce_todolist.lfm
@@ -29,31 +29,32 @@ inherited CETodoListWidget: TCETodoListWidget
item
AutoSize = True
Caption = 'text'
- Width = 36
+ Width = 34
end
item
AutoSize = True
Caption = 'category'
- Width = 67
+ Width = 65
end
item
AutoSize = True
Caption = 'assignee'
- Width = 68
+ Width = 66
end
item
AutoSize = True
Caption = 'status'
+ Width = 48
end
item
AutoSize = True
Caption = 'priority'
- Width = 57
+ Width = 55
end
item
AutoSize = True
Caption = 'file'
- Width = 278
+ Width = 291
end>
ReadOnly = True
SortType = stText
diff --git a/src/ce_todolist.pas b/src/ce_todolist.pas
index afef5e43..49ca262c 100644
--- a/src/ce_todolist.pas
+++ b/src/ce_todolist.pas
@@ -230,7 +230,7 @@ begin
lstfilter.OnChange := @filterItems;
btnGo.OnClick := @handleListClick;
- fname := getCoeditDocPath + OptFname;
+ fname := getDocPath + OptFname;
if fname.fileExists then
begin
fOptions.loadFromFile(fname);
@@ -242,7 +242,7 @@ end;
destructor TCETodoListWidget.Destroy;
begin
- fOptions.saveToFile(getCoeditDocPath + OptFname);
+ fOptions.saveToFile(getDocPath + OptFname);
killToolProcess;
inherited;
end;
diff --git a/src/ce_tools.pas b/src/ce_tools.pas
index 53d18909..0d158346 100644
--- a/src/ce_tools.pas
+++ b/src/ce_tools.pas
@@ -287,7 +287,7 @@ var
begin
inherited;
fTools := TCEToolItems.Create(TCEToolItem);
- fname := getCoeditDocPath + toolsFname;
+ fname := getDocPath + toolsFname;
if fname.fileExists then
loadFromFile(fname);
@@ -298,8 +298,8 @@ destructor TCETools.destroy;
begin
EntitiesConnector.removeObserver(self);
- ForceDirectoriesUTF8(getCoeditDocPath);
- saveToFile(getCoeditDocPath + toolsFname);
+ ForceDirectoriesUTF8(getDocPath);
+ saveToFile(getDocPath + toolsFname);
fTools.Free;
inherited;
end;
diff --git a/src/ce_common.pas b/src/ce_common.pas
index ff73b885..5e83bec8 100644
--- a/src/ce_common.pas
+++ b/src/ce_common.pas
@@ -190,9 +190,9 @@ type
function getUserDataPath: string;
(**
* Returns the folder where Coedit stores the data, the cache, the settings.
*)
- function getCoeditDocPath: string;
+ function getDocPath: string;
(**
* Fills aList with the names of the files located in aPath.
@@ -291,7 +291,7 @@ type
function isDlangCompilable(const ext: string): boolean;
(**
* Returns true if ext matches a file extension whose type is editable in Coedit.
*)
function isEditable(const ext: string): boolean;
@@ -771,14 +771,14 @@ begin
result := sysutils.GetEnvironmentVariable('HOME') + '/Library/Application Support';
{$ENDIF}
if not DirectoryExists(result) then
- raise Exception.Create('Coedit failed to retrieve the user data folder');
+ raise Exception.Create('dexed failed to retrieve the user data folder');
if result[result.length] <> DirectorySeparator then
result += directorySeparator;
end;
-function getCoeditDocPath: string;
+function getDocPath: string;
begin
- result := getUserDataPath + 'Coedit' + directorySeparator;
+ result := getUserDataPath + 'dexed' + directorySeparator;
end;
function isFolder(sr: TSearchRec): boolean;
@@ -190,9 +190,9 @@ type
function getUserDataPath: string;
(**
- * Returns the folder where Coedit stores the data, the cache, the settings.
+ * Returns the folder where Dexed stores the data, the cache, the settings.
*)
@@ -291,7 +291,7 @@ type
function isDlangCompilable(const ext: string): boolean;
(**
- * Returns true if ext matches a file extension whose type is editable in Coedit.
+ * Returns true if ext matches a file extension whose type is editable in Dexed.
*)
function isEditable(const ext: string): boolean;